@@ -1,8 +1,8 @@
 #! /usr/bin/env python
 # -*- coding: utf-8 -*-
 
-__version_info__ = ('0', '2', '5')
+__version_info__ = ('0', '3', '0')
 __version__ = '.'.join(__version_info__)
 __author__ = 'R. Patrick Xian, others'
 
-from . import dict_io, json_io
\ No newline at end of file
+from . import dict_io, json_io, mat_io
\ No newline at end of file
